import os
from pathlib import Path
from subprocess import check_call


def install_win():

    Path(Path(os.path.expanduser('~')).root +
         "lockerlite.txt").write_text(Path('KonbiLockerLite/install/lockerlite_linux.py').read_text())


def install_linux():
    print('running install_linux')
    print(Path('KonbiLockerLite/install/lockerlite_linux.py').absolute())
    Path("/usr/bin/lockerlite").write_text(
        Path('KonbiLockerLite/install/lockerlite_linux.py').read_text())
    check_call("chmod +x /usr/bin/lockerlite".split())


def install():
    # create execution entry
    if os.name == 'nt':
        install_win()
    elif os.name == 'posix':
        install_linux()


Path().root



#!/usr/bin/python3

import sys

# Run the main entry point, similarly to how setuptools d$
# we didn't install the actual entry point from setup.py,$
# pkg_resources API.
import KonbiLockerLite

from KonbiLockerLite import LockerLite

args = sys.argv
if len(args) > 1:
    if args[1].lower() == 'setup':
        LockerLite.setup()
else:
    LockerLite.run()



import sys
import os
from pathlib import Path
import json
import BarcodeScanner
from Locker import Locker

config_file = Path(os.path.expanduser('~') + '/lockerlite.json')
config = {}
if config_file.exists():
    config = json.loads(config_file.read_text())

def setup():
    
    hid_device = ''
    while(hid_device == ''):
        hids = Path('/dev').glob('hidraw*')
        selectable_hid = []
        for hid in hids:
            selectable_hid.append(str(hid.absolute()))
        selectable_hid.sort()
        index = 1        
        selected = config.get('scanner','')
        if selected != '':
            selected = '(Selected: '+ selected +')'
        while index <= len(selectable_hid):
            print('\t ' + str(index) + ') ' + selectable_hid[index-1])
            index += 1

        selected_hid = input('Please select Barcode device '+selected+':')

        try:
            selected_hid_index = int(selected_hid)
        except ValueError:
            print('Invalid selection')
        else:

            if selected_hid_index > len(selectable_hid):
                print('Invalid selection')
            else:
                hid_device = selectable_hid[selected_hid_index-1]
        config["scanner"] = hid_device
        config_file.write_text(json.dumps(config))
    usb_device =''
    while(usb_device == ''):
        usbs = Path('/dev').glob('ttyUSB*')
        selectable_usb = []
        for usb in usbs:
            selectable_usb.append(str(usb.absolute()))
        selectable_usb.sort()
        index = 1
        selected = config.get('locker','')
        if selected != '':
            selected = '(Selected: '+ selected +')'
        while index <= len(selectable_usb):
            print('\t ' + str(index) + ') ' + selectable_usb[index-1])
            index += 1

        selected_usb = input('Please select Locker Port '+selected+':')

        try:
            selected_usb_index = int(selected_usb)
        except ValueError:
            print('Invalid selection')
        else:

            if selected_usb_index > len(selectable_usb):
                print('Invalid selection')
            else:
                usb_device = selectable_usb[selected_usb_index-1]
        config["locker"] = usb_device
        config_file.write_text(json.dumps(config))
        mapping_file = Path(os.path.expanduser('~') + '/lockerlite_mapping.json')
        if not mapping_file.exists():
            mapping_list = {
                '101': '01',
                '102': '02',
                '103': '03',
                '104': '04',
                '105': '05',
                '106': '06',
                '107': '07',
                '108': '08',
                '109': '09',
                '110': '010',
                '201': '11',
                '202': '12',
                '203': '13',
                '204': '14',
                '205': '15',
                '206': '16',
                '207': '17',
                '208': '18',
                '209': '19',
                '210': '110'
                }
            mapping_file.write_text(json.dumps(mapping_list))
        print(config)
        

def run():    
    if config.get('scanner','')!='':
        locker = Locker(config.get('locker',''))
        print('Start locket with config: ' +str(config))
        print('^C to quit')
        try:
            BarcodeScanner.listen_scanner(config["scanner"],locker.open_slot)
        except KeyboardInterrupt:
            print(' to quit')
    else:
        print('barcode scanner is not set yet. let run lockerlite setup to config scanner & locker port')
    


if __name__ == "__main__":
    print(sys.argv)
    print(config_file)
    if len(sys.argv)>=2 and sys.argv[1].lower() == 'setup':
        setup()
    else:
        run()



import setuptools
from setuptools.command.develop import develop
from setuptools.command.install import install
from pathlib import Path
from KonbiLockerLite.install import LockerLiteInstall


class PostDevelopCommand(develop):
    """Post-installation for development mode."""

    def run(self):
        # PUT YOUR POST-INSTALL SCRIPT HERE or CALL A FUNCTION
        LockerLiteInstall.install()
        develop.run(self)


class PostInstallCommand(install):
    """Post-installation for installation mode."""

    def run(self):
        LockerLiteInstall.install()
        install.run(self)


setuptools.setup(
    name="KonbiLockerLite",
    version="0.2.2",
    long_description=Path("README.md").read_text(),
    packages=setuptools.find_packages(),
    cmdclass={
        'develop': PostDevelopCommand,
        'install': PostInstallCommand
    },
)



import os
from pathlib import Path
import json
import serial
import time
from crccheck.crc import Crc16


class Locker:
    def __init__(self, port):
        self.port = port
        self.location_mapping = {}
        mapping_file = Path(os.path.expanduser(
            '~') + '/lockerlite_mapping.json')
        if mapping_file.exists():
            self.location_mapping = json.loads(mapping_file.read_text())

    def get_location(self, location):
        cabinet = 0
        slot = 0
        code = self.location_mapping.get(str(location), '')
        if len(code) < 2:
            raise ValueError('location: ' + str(location) +
                             ' code: ' + code + ' - is invalid')

        cabinet = int(code[0:1])
        slot = int(code[1:])
        return (cabinet, slot)

    def calcCrc(barray):
        num = 0
        for idx, value in enumerate(list(barray)):
            num ^= value << 8
            for idx2 in range(8):
                if (num & 32768) != 0:
                    num = num << 1 ^ 4129
                else:
                    num <<= 1

    def open(self, cabinet, slots):

        open_success = False

        with serial.Serial() as ser:
            ser.port = self.port
            ser.open()

            # PCToDrivingBoard
            bytes = bytearray.fromhex('C7')
            # number of slots
            if len(slots) > 0:
                bytes.append(6+len(slots))
            else:
                bytes.append(7)
            # cabinet
            bytes.append(cabinet)
            # RequestToOpen
            bytearray.extend(bytes, bytearray.fromhex('52'))
            # cabinet
            bytes.append(cabinet)
            bytes.append(0)

            bytearray.extend(bytes, bytearray(slots))

            bytes.append(0)
            bytes.append(0)

            # calculate crc
            crc = Crc16.calc(bytes)

            bytes = bytes[0:-2]

            bytearray.extend(bytes, bytearray(
                crc.to_bytes(2, byteorder='big')))

            print('write to Serial Port', "".join("%02x " % b for b in bytes))
            ser.write(bytes)
            open_success = ser.is_open

        return open_success

    def open_slot(self, barcode):
        locations = json.loads(barcode)
        print(locations)
        for location in locations:
            cabinet, slot = self.get_location(location)
            result = self.open(cabinet, [slot])
            if result:
                print('open success', 'cabinet: ' +
                      str(cabinet), 'slot: ' + str(slot))
            else:
                print('fail to open', 'cabinet: ' +
                      str(cabinet), 'slot: ' + str(slot))
